@@ -50,7 +50,22 @@
 #define AFT_PORT6_OFFSET		0x18000
 #define AFT_PORT7_OFFSET		0x1C000
 
-#define AFT_PORT_REG(card,reg)		(reg+(0x4000*card->wandev.comm_port))
+static __inline u32 AFT_PORT_REG(sdla_t *card, u32 reg)
+{
+	if (card->adptr_type == AFT_ADPTR_A600) {
+		if (reg < 0x100) {
+			return (reg+0x1000);
+		} else {
+			return (reg+0x2000);
+		}
+	} else {
+		if (reg < 0x100) {
+			return reg;	
+		}
+		return 	(reg+(0x4000*card->wandev.comm_port));
+	}
+}
+
 
 /*======================================================
  * GLOBAL  (All Ports)
@@ -99,6 +114,9 @@
 # define AFT_CHIPCFG_A200_EC_SEC_KEY_MASK	0x3
 # define AFT_CHIPCFG_A200_EC_SEC_KEY_SHIFT  	16 
 
+# define AFT_CHIPCFG_A600_EC_SEC_KEY_MASK	0x3
+# define AFT_CHIPCFG_A600_EC_SEC_KEY_SHIFT  	4
+
 # define AFT_CHIPCFG_SPI_SLOW_BIT	5	/* Slow down SPI */
 #if 0
 # define AFT_CHIPCFG_EC_INTR_CFG_BIT	4	/* Shark or Analog */
@@ -186,7 +204,16 @@
 #  define AFT_CHIPCFG_WDT_TX_INTR_STAT  1
 #  define AFT_CHIPCFG_WDT_RX_INTR_STAT	2
 
-
+# define AFT_CLKCFG_A600_CLK_OUTPUT_BIT         0
+# define AFT_CLKCFG_A600_CLK_EXT_CLK_SRC_BIT    4
+# define AFT_CLKCFG_A600_CLK_SRC_BIT_MASK       0x6
+# define AFT_CLKCFG_A600_CLK_SRC_BIT_SHIFT      1
+# define AFT_CLKCFG_A600_CLK_OUT_BIT_MASK       0x7
+# define AFT_CLKCFG_A600_CLK_OUT_BIT_SHIFT      5
+# define AFT_CLKCFG_A600_CLK_SRC_OSC            0x00
+# define AFT_CLKCFG_A600_CLK_SRC_EXT_NO_PLL     0x01
+# define AFT_CLKCFG_A600_CLK_SRC_EXT_PLL        0x02
+# define AFT_CLKCFG_A600_CLK_OUT_BOARD          0x04
 
 /* A104 & A104D Interrupt Status Funcitons */
 
@@ -310,16 +337,11 @@ aft_chipcfg_a108_get_tdmv_intr_stats(u32 reg)
 /* Serial specific functions */
 
 static __inline u32
-aft_chipcfg_serial_get_status_intr_stats(u32 reg, int port)
+aft_chipcfg_serial_get_status_intr_stats(u32 reg)
 {
 	reg=reg>>AFT_CHIPCFG_SERIAL_STATUS_INTR_SHIFT;
 	reg&=AFT_CHIPCFG_SERIAL_STATUS_INTR_MASK;
 	
-	if (port) {
-		port--;
-	}
-	reg=(reg>>(3*port))&0x07;
-
 	return reg;
 }
 
@@ -404,7 +426,22 @@ aft_chipcfg_get_a200_ec_channels(u32 reg)
 	}
 	
 	return 0;
-}        
+}
+
+static __inline u32
+aft_chipcfg_get_a600_ec_channels(u32 reg)
+{
+	switch ((reg>>AFT_CHIPCFG_A600_EC_SEC_KEY_SHIFT)&AFT_CHIPCFG_A600_EC_SEC_KEY_MASK){
+		case 0x00:
+			return 0;
+		case 0x01:
+			return 5;
+		default:
+			return 0;
+	}
+	
+	return 0;
+}
 
 # define AFT_WDTCTRL_MASK		0xFF
 # define AFT_WDTCTRL_TIMEOUT 		75	/* ms */
@@ -1577,6 +1614,7 @@ enum {
 #define AFT_SERIAL_MIN_FRMW_VER	0x04
 
 #define AFT_MIN_ANALOG_FRMW_VER 0x05
+#define AFT_MIN_A600_FRMW_VER 	0x01
 
 #define A500_MAX_EC_CHANS 64
 
