@@ -836,6 +836,9 @@ static int probe_get_info(char* buf, char** start, off_t offs, int len, int dumm
 	if (hw_cnt->aft300_adapters){
 		PROC_ADD_LINE(m, "A300=%d ", hw_cnt->aft300_adapters);
 	}
+	if (hw_cnt->aft_a600_adapters){
+		PROC_ADD_LINE(m, "A600=%d ", hw_cnt->aft_a600_adapters);
+	}
 	PROC_ADD_LINE(m, "\n");
 
 	PROC_ADD_RET(m);
@@ -877,7 +880,7 @@ static int probe_get_info_legacy(char* buf, char** start, off_t offs, int len, i
 	hw_cnt=(sdla_hw_type_cnt_t*)sdla_get_hw_adptr_cnt();	
 	
 	PROC_ADD_LINE(m,
-		"\nCard Cnt: S508=%d S514X=%d S518=%d A101-2=%d A104=%d A300=%d A200=%d A108=%d A056=%d\n          A500=%d A14x=%d\n",
+		"\nCard Cnt: S508=%d S514X=%d S518=%d A101-2=%d A104=%d A300=%d A200=%d A108=%d A056=%d\n          A500=%d A14x=%d A600=%d\n",
 		hw_cnt->s508_adapters,
 		hw_cnt->s514x_adapters,
 		hw_cnt->s518_adapters,
@@ -888,7 +891,8 @@ static int probe_get_info_legacy(char* buf, char** start, off_t offs, int len, i
 		hw_cnt->aft108_adapters,
 		hw_cnt->aft_56k_adapters,
 		hw_cnt->aft_isdn_adapters,
-		hw_cnt->aft_serial_adapters
+		hw_cnt->aft_serial_adapters,
+		hw_cnt->aft_a600_adapters
 		);
 
 	PROC_ADD_RET(m);
@@ -965,6 +969,9 @@ static int probe_get_info_verbose(char* buf, char** start, off_t offs, int len,
 	if (hw_cnt->aft300_adapters){
 		PROC_ADD_LINE(m, "A300=%d ", hw_cnt->aft300_adapters);
 	}
+	if (hw_cnt->aft_a600_adapters){
+		PROC_ADD_LINE(m, "A600=%d ", hw_cnt->aft_a600_adapters);
+	}
 	PROC_ADD_LINE(m, "\n");
 
 	PROC_ADD_RET(m);
